========
Contents
========

**Python Extension to the Swiss Ephemeris** -- *Ephemeris for developers of
astrological software*

.. image:: image001.png
    :align: center

Original documentation is Copyright Astrodienst AG 1997-2021

:Authors: Dieter Koch and Dr. Alois Treindl
:Website: https://www.astro.com/swisseph
:Mailing-list: https://groups.io/g/swisseph/

.. note::

    This version of the documention, adapted for the Python programming
    language, is a work in progress.
    Head to https://github.com/astrorigin/pyswisseph if you want to
    participate.

.. toctree::
    :maxdepth: 2

    introduction
    The ephemerides <ephemerides/index>
    apparent_vs_true_planetary_positions
    geo_topo_helio_bary_and_planetocentric_positions
    heliacal_events_eclipses_occultations_etc/index
    sidereal_time_ascendant_mc_houses_vertex/index
    delta_t
    programmers_manual/index


Indices and tables
==================

* :ref:`Index of functions <genindex>`

.. * :ref:`modindex`
.. * :ref:`search`

..
